@@ -12,44 +12,36 @@
 
 #include <chrono>
 
-#include <KAboutData>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KPluginFactory>
 #include <KSharedConfig>
-#include <QStandardPaths>
-
-#include <KLocalizedString>
 
 #include <KAuth/Action>
 #include <KAuth/ExecuteJob>
 
-#include <KNewStuff3/KNSCore/EntryInternal>
-
 #include <kio/job.h>
 
 using namespace std::chrono_literals;
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMPlymouthFactory, "kcm_plymouth.json", registerPlugin<KCMPlymouth>();)
+K_PLUGIN_CLASS_WITH_JSON(KCMPlymouth, "kcm_plymouth.json")
 
-KCMPlymouth::KCMPlymouth(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ConfigModule(parent, args)
+KCMPlymouth::KCMPlymouth(QObject *parent, const KPluginMetaData &metaData)
+    : KQuickConfigModule(parent, metaData)
     , m_model(new QStandardItemModel(this))
 {
     qmlRegisterAnonymousType<QStandardItemModel>("KCMPlymouth", 1);
     qmlRegisterAnonymousType<KCMPlymouth>("KCMPlymouth", 1);
-    KAboutData *about =
-        new KAboutData(QStringLiteral("kcm_plymouth"), i18n("Boot Splash Screen"), QStringLiteral(PROJECT_VERSION), QString(), KAboutLicense::LGPL);
-    about->addAuthor(i18n("Marco Martin"), QString(), QStringLiteral("mart@kde.org"));
-    setAboutData(about);
     setButtons(Apply);
     setAuthActionName(QStringLiteral("org.kde.kcontrol.kcmplymouth.save"));
-    setNeedsAuthorization(true);
 
-    m_model->setItemRoleNames({{Qt::DisplayRole, QByteArrayLiteral("display")},
-                               {DescriptionRole, QByteArrayLiteral("description")},
-                               {PluginNameRole, QByteArrayLiteral("pluginName")},
-                               {ScreenhotRole, QByteArrayLiteral("screenshot")},
-                               {UninstallableRole, QByteArrayLiteral("uninstallable")}});
+    m_model->setItemRoleNames({
+        {Qt::DisplayRole, QByteArrayLiteral("display")},
+        {DescriptionRole, QByteArrayLiteral("description")},
+        {PluginNameRole, QByteArrayLiteral("pluginName")},
+        {ScreenhotRole, QByteArrayLiteral("screenshot")},
+        {UninstallableRole, QByteArrayLiteral("uninstallable")},
+    });
 }
 
 KCMPlymouth::~KCMPlymouth()
@@ -65,7 +57,7 @@ void KCMPlymouth::reloadModel()
         return;
     }
 
-    KConfigGroup installedCg(KSharedConfig::openConfig(QStringLiteral("kplymouththemeinstallerrc")), "DownloadedThemes");
+    KConfigGroup installedCg(KSharedConfig::openConfig(QStringLiteral("kplymouththemeinstallerrc")), QStringLiteral("DownloadedThemes"));
 
     dir.setFilter(QDir::NoDotAndDotDot | QDir::Dirs);
 
@@ -75,7 +67,7 @@ void KCMPlymouth::reloadModel()
         QDir themeDir(fileInfo.filePath());
 
         KConfig file(themeDir.filePath(pluginName + QLatin1String(".plymouth")), KConfig::SimpleConfig);
-        KConfigGroup grp = file.group("Plymouth Theme");
+        KConfigGroup grp = file.group(QStringLiteral("Plymouth Theme"));
 
         QString displayName = grp.readEntry("Name", QString());
         if (displayName.isEmpty()) {
@@ -89,14 +81,14 @@ void KCMPlymouth::reloadModel()
 
         // the theme has a preview
         if (QFile::exists(themeDir.path() + QStringLiteral("/preview.png"))) {
-            row->setData(QString(themeDir.path() + QStringLiteral("/preview.png")), ScreenhotRole);
+            row->setData(QUrl::fromLocalFile(themeDir.path() + QStringLiteral("/preview.png")), ScreenhotRole);
             // fetch it downloaded from kns
         } else {
             const QString fileName = installedCg.readEntry(fileInfo.fileName(), QString());
             if (fileName.isEmpty()) {
                 row->setData(QString(), ScreenhotRole);
             } else {
-                row->setData(fileName + QStringLiteral(".png"), ScreenhotRole);
+                row->setData(QUrl::fromLocalFile(fileName + QStringLiteral(".png")), ScreenhotRole);
             }
         }
 
@@ -106,18 +98,15 @@ void KCMPlymouth::reloadModel()
     Q_EMIT selectedPluginIndexChanged();
 }
 
-void KCMPlymouth::onChangedEntriesChanged(const QQmlListReference &changedEntries)
+void KCMPlymouth::onEntryEvent(const KNSCore::Entry &entry)
 {
     static QStringList alreadyCopiedThumbnails;
-    for (int i = 0; i < changedEntries.count(); ++i) {
-        auto entry = qobject_cast<KNSCore::EntryWrapper *>(changedEntries.at(i))->entry();
-        if (entry.isValid() && entry.status() == KNS3::Entry::Installed && !alreadyCopiedThumbnails.contains(entry.uniqueId())) {
-            alreadyCopiedThumbnails.append(entry.uniqueId());
-            KIO::file_copy(QUrl(entry.previewUrl(KNSCore::EntryInternal::PreviewBig1)),
-                           QUrl::fromLocalFile(QString(entry.installedFiles().constFirst() + QStringLiteral(".png"))),
-                           -1,
-                           KIO::Overwrite | KIO::HideProgressInfo);
-        }
+    if (entry.isValid() && entry.status() == KNSCore::Entry::Installed && !alreadyCopiedThumbnails.contains(entry.uniqueId())) {
+        alreadyCopiedThumbnails.append(entry.uniqueId());
+        KIO::file_copy(QUrl(entry.previewUrl(KNSCore::Entry::PreviewBig1)),
+                       QUrl::fromLocalFile(QString(entry.installedFiles().constFirst() + QStringLiteral(".png"))),
+                       -1,
+                       KIO::Overwrite | KIO::HideProgressInfo);
     }
     reloadModel();
 }
@@ -174,7 +163,7 @@ void KCMPlymouth::load()
 {
     reloadModel();
 
-    KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral(PLYMOUTH_CONFIG_PATH)), "Daemon");
+    KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral(PLYMOUTH_CONFIG_PATH)), QStringLiteral("Daemon"));
 
     setSelectedPlugin(cg.readEntry("Theme"));
 
@@ -221,7 +210,7 @@ void KCMPlymouth::uninstall(const QString &plugin)
     if (!rc) {
         Q_EMIT showErrorMessage(i18n("Unable to authenticate/execute the action: %1 (%2)", job->error(), job->errorString()));
     } else {
-        KConfigGroup installedCg(KSharedConfig::openConfig(QStringLiteral("kplymouththemeinstallerrc")), "DownloadedThemes");
+        KConfigGroup installedCg(KSharedConfig::openConfig(QStringLiteral("kplymouththemeinstallerrc")), QStringLiteral("DownloadedThemes"));
         installedCg.deleteEntry(plugin);
         Q_EMIT showSuccessMessage(i18n("Theme uninstalled successfully."));
         load();
@@ -237,3 +226,5 @@ void KCMPlymouth::defaults()
 }
 
 #include "kcm.moc"
+
+#include "moc_kcm.cpp"
